<?php
if (!class_exists('FujirouCommon')) {
    if (file_exists(__DIR__.'/fujirou_common.php')) {
        include_once(__DIR__.'/fujirou_common.php');
    } else if (file_exists(__DIR__.'/../../include/fujirou_common.php')) {
        include_once(__DIR__.'/../../include/fujirou_common.php');
    }
}

class FujirouMetroLyrics {
    private $_site = 'http://www.metrolyrics.com';
    private $_apiSite = 'http://api.metrolyrics.com';
    private $_apiKey = '196f657a46afb63ce3fd2015b9ed781280337ea7';

    public function __construct() {
    }

    public function getLyricsList($artist, $title, $info) {
        return $this->search($info, $artist, $title);
    }
    public function getLyrics($id, $info) {
        return $this->get($info, $id);
    }

    public function search($handle, $artist, $title) {
        $count = 0;

        $keyword = sprintf("%s %s", $artist, $title);

        // http://www.metrolyrics.com/api/v1/multisearch/all/X-API-KEY/196f657a46afb63ce3fd2015b9ed781280337ea7?find=taylor+swift+love+stor
        // http://api.metrolyrics.com/v1//multisearch/all/X-API-KEY/196f657a46afb63ce3fd2015b9ed781280337ea7/format/json?find=taylor+swift+fifteen&theme=desktop
        // http://api.metrolyrics.com/v1/
        $searchUrl = sprintf(
//             "%s/v1/search/artistsong/artist/%s/song/%s/X-API-KEY/%s/format/json",
//             "%s/v1/search/artistsong?artist=%s&song=%s&X-API-KEY=%s&format=json",
            "%s/v1//multisearch/all/X-API-KEY/%s/format/json?find=%s",
            $this->_apiSite, $this->_apiKey, rawurlencode(sprintf('%s %s', $artist, $title))
//             $this->_site, rawurlencode($artist), rawurlencode($title), $this->_apiKey
        );

        $content = FujirouCommon::getContent($searchUrl);
        if (!$content) {
            return $count;
        }

        $list = $this->parseSearchResult($content);

        for ($idx = 0; $idx < count($list); $idx++) {
            $obj = $list[$idx];

            $handle->addTrackInfoToList(
                $obj['artist'],
                $obj['title'],
                $obj['id'],
                $obj['partial']
            );
        }

        return count($list);
    }

    public function get($handle, $id) {
        $lyric = '';

        $content = FujirouCommon::getContent($id);
        if (!$content) {
            return FALSE;
        }

        $prefix = '<div class="lyrics-body">';
        $suffix = '</div>';

        $lyric = FujirouCommon::getSubString($content, $prefix, $suffix);

        $lyric = str_replace('<br />', "\n", $lyric);
        $lyric = str_replace("<p class='verse'>", "\n\n", $lyric);
        $lyric = trim(strip_tags($lyric));
        $lyric = FujirouCommon::decodeHTML($lyric);

        // remove extra ad line
        $pattern = '/\[ From: http:\/\/www.metrolyrics.com\/.*.html \]/';
        $lyric = preg_replace($pattern, '', $lyric);

        $handle->addLyrics($lyric, $id);

        return true;
    }

    private function parseSearchResult($content) {
        $result = array();

        $json = json_decode($content, TRUE);

        if (!$json) {
            return $result;
        }

        if (!array_key_exists('results', $json) || count($json['results']) <= 0) {
            return $result;
        }
        if (!array_key_exists('songs', $json['results']) || count($json['results']['songs']) <= 0) {
            return $result;
        }

        $songs = $json['results']['songs'];
        if (!array_key_exists('d', $songs) || count($songs['d']) <= 0) {
            return $result;
        }

        $item = $songs['d'][0];

        $infos = explode('<br />', $item['p']);
        $title = strip_tags($infos[0]);
        $artist = strip_tags($infos[1]);

        $item = array(
            'artist' => $artist,
            'title'  => $title,
            'id'     => sprintf("%s/%s", $this->_site, $item['u']),
            'partial'=> ''
        );

        array_push($result, $item);

        return $result;
    }
}

if (!debug_backtrace()) {
    class TestObj {
        private $items;

        function __construct() {
            $this->items = array();
        }

        public function addLyrics($lyric, $id) {
            printf("\n");
            printf("song id: %s\n", $id);
            printf("\n");
            printf("== lyric ==\n");
            printf("%s\n", $lyric);
            printf("** END of lyric **\n\n");
        }

        public function addTrackInfoToList($artist, $title, $id, $prefix) {
            printf("\n");
            printf("song id: %s\n", $id);
            printf("%s - %s\n", $artist, $title);
            printf("\n");
            printf("== prefix ==\n");
            printf("%s\n", $prefix);
            printf("** END of prefix **\n\n");

            array_push($this->items, array(
                'artist' => $artist,
                'title'  => $title,
                'id'     => $id
            ));
        }

        function getItems() {
            return $this->items;
        }
        function getFirstItem() {
            if (count($this->items) > 0) {
                return $this->items[0];
            } else {
                return FALSE;
            }
        }
    }

    $module = 'FujirouMetroLyrics';
//     $artist = 'pitbull';
//     $title = 'We Are One (Ole Ola)';
//     $title = 'red (original demo version)';
//     $title = 'album red';
//     $artist = 'taylor swift';
//     $title = 'style';

    $artist = 'Usher';
    $title = 'Lovers & Friends';


    $refClass = new ReflectionClass($module);
    $obj = $refClass->newInstance();
    
    $testObj = new TestObj();
    $count = $obj->search($testObj, $artist, $title);

    if ($count > 0) {
        $item = $testObj->getFirstItem();

        if (array_key_exists('id', $item)) {
            $obj->get($testObj, $item['id']);
        } else {
            echo "\nno id to query lyric\n";
        }
    }
}
// vim: expandtab ts=4
?>

